labeltools.label_logical_ties_in_expr_with_written_logical_tie_duration
=======================================================================

.. autofunction:: abjad.tools.labeltools.label_logical_ties_in_expr_with_written_logical_tie_duration.label_logical_ties_in_expr_with_written_logical_tie_duration
